@@ -19,7 +19,9 @@ function(x, extent=drawExtent(), maxpixels=100000, layer=1, new=TRUE, ...) {
 	}
 	extent <- extent  # force to start with drawing before creating a new graphics device
 	if (new) { dev.new() }
-	if (class(x) != 'RasterLayer') { x <- raster(x,layer) }
+	if (nlayers(x) > 1) { 
+		x <- raster(x, layer) 
+	}
 	.plotraster(x, maxpixels=maxpixels, extent=extent, ...) 	
 	return(invisible(extent))
 }
